==> neptune_ui-2.1.0.214.jar: com/tandbergtv/neptune/ui/realm/client/alerts/service/IAlertsUIService.java <==
package com.tandbergtv.neptune.ui.realm.client.alerts.service;

import java.util.List;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;
import com.tandbergtv.neptune.widgettoolkit.client.application.NeptuneException;

@RemoteServiceRelativePath("service/realm/IAlertsUIService")
public interface IAlertsUIService  extends RemoteService {

	/**
	 * 		Return count for all alert types.
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	UiAlertCounts getAlertCounts() throws NeptuneException;

	/**
	 * 		Return all the aggregated alert items.
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	List<UiAlertItem> getAlertItems() throws NeptuneException;

	/**
	 * 		Return list of aggregated alert items , given the index and page size
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	List<UiAlertItem> getAlertItems(int index, int pageSize) throws NeptuneException;
	
	/**
	 *  Attempts to fix the {@code UiRecoveryItem} using the specified URL and any
	 *  associated parameters
	 * 
	 * @param UiRecoveryItem recoveryItem the item to recover
	 * @return the status of the call
	 */
	String recover(UiRecoveryItem recoveryItem);	
	
	/**
	 *  Attempts to fix all of the {@code UiRecoveryItem}s in the provided list
	 * 
	 * @param List<UiRecoveryItem> recoveryItems the list of recovery options to recover
	 * @return the status of each call in the list of recovery options 
	 */
	List<String> recoverAll(List<UiRecoveryItem> recoveryItems);
}

==> neptune_ui-2.3.0.226.jar: com/tandbergtv/neptune/ui/realm/client/alerts/service/IAlertsUIService.java <==
package com.tandbergtv.neptune.ui.realm.client.alerts.service;

import java.util.List;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;
import com.tandbergtv.neptune.widgettoolkit.client.application.NeptuneException;

@RemoteServiceRelativePath("service/realm/IAlertsUIService")
public interface IAlertsUIService  extends RemoteService {

	/**
	 * 		Return count for all alert types.
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	UiAlertCounts getAlertCounts() throws NeptuneException;

	/**
	 * 		Return all the aggregated alert items.
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	List<UiAlertItem> getAlertItems() throws NeptuneException;

	/**
	 * 		Return list of aggregated alert items , given the index and page size
	 * 
	 * @return
	 * @throws NeptuneException
	 */
	List<UiAlertItem> getAlertItems(int index, int pageSize) throws NeptuneException;
	
	/**
	 *  Attempts to fix the {@code UiRecoveryItem} using the specified URL and any
	 *  associated parameters
	 * 
	 * @param UiRecoveryItem recoveryItem the item to recover
	 * @return the status of the call
	 */
	String recover(UiRecoveryItem recoveryItem) throws NeptuneException;	
	
	/**
	 *  Attempts to fix all of the {@code UiRecoveryItem}s in the provided list
	 * 
	 * @param List<UiRecoveryItem> recoveryItems the list of recovery options to recover
	 * @return the status of each call in the list of recovery options 
	 * @throws Exception 
	 */
	List<String> recoverAll(List<UiRecoveryItem> recoveryItems) throws NeptuneException;
}
